from constants.statuses import BaseStatuses, StatusOptions


class PipelineStatuses(BaseStatuses):
    CREATED = StatusOptions.CREATED
    WARNING = StatusOptions.WARNING
    SCHEDULED = StatusOptions.SCHEDULED
    RUNNING = StatusOptions.RUNNING
    FINISHED = StatusOptions.FINISHED
    STOPPED = StatusOptions.STOPPED
    SKIPPED = StatusOptions.SKIPPED

    VALUES = {
        CREATED, WARNING, SCHEDULED, RUNNING, FINISHED, STOPPED, SKIPPED
    }
    CHOICES = (
        (CREATED, CREATED),
        (WARNING, WARNING),
        (SCHEDULED, SCHEDULED),
        (RUNNING, RUNNING),
        (FINISHED, FINISHED),
        (STOPPED, STOPPED),
        (SKIPPED, SKIPPED),
    )

    DONE_STATUS = {FINISHED, STOPPED, SKIPPED}
    RUNNING_STATUS = {SCHEDULED, RUNNING}
    FAILED_STATUS = set([])

    TRANSITION_MATRIX = {
        CREATED: {None, },
        SCHEDULED: {CREATED, WARNING, },
        RUNNING: {SCHEDULED, WARNING, },
        FINISHED: {CREATED, SCHEDULED, RUNNING, WARNING, },
        STOPPED: {CREATED, SCHEDULED, RUNNING, WARNING, },
        SKIPPED: {CREATED, SCHEDULED, STOPPED, WARNING, },
        WARNING: set(VALUES) - {FINISHED, STOPPED, SKIPPED, STOPPED, WARNING, }
    }


class OperationStatuses(BaseStatuses):
    CREATED = StatusOptions.CREATED
    WARNING = StatusOptions.WARNING
    SCHEDULED = StatusOptions.SCHEDULED
    RUNNING = StatusOptions.RUNNING
    SUCCEEDED = StatusOptions.SUCCEEDED
    FAILED = StatusOptions.FAILED
    UPSTREAM_FAILED = StatusOptions.UPSTREAM_FAILED
    STOPPED = StatusOptions.STOPPED
    SKIPPED = StatusOptions.SKIPPED
    RETRYING = StatusOptions.RETRYING

    VALUES = {
        CREATED, WARNING, SCHEDULED, RUNNING,
        SUCCEEDED, FAILED, UPSTREAM_FAILED, STOPPED, SKIPPED, RETRYING
    }
    CHOICES = (
        (CREATED, CREATED),
        (WARNING, WARNING),
        (SCHEDULED, SCHEDULED),
        (RUNNING, RUNNING),
        (SUCCEEDED, SUCCEEDED),
        (FAILED, FAILED),
        (UPSTREAM_FAILED, UPSTREAM_FAILED),
        (STOPPED, STOPPED),
        (SKIPPED, SKIPPED),
        (RETRYING, RETRYING)
    )

    DONE_STATUS = {SUCCEEDED, FAILED, UPSTREAM_FAILED, STOPPED, SKIPPED}
    RUNNING_STATUS = {SCHEDULED, RUNNING}
    FAILED_STATUS = {FAILED, UPSTREAM_FAILED}

    TRANSITION_MATRIX = {
        CREATED: {None, },
        SCHEDULED: {CREATED, RETRYING, WARNING, },
        RUNNING: {SCHEDULED, WARNING, },
        SUCCEEDED: {RUNNING, WARNING, },
        FAILED: {SCHEDULED, RUNNING, WARNING, },
        UPSTREAM_FAILED: set(VALUES) - {UPSTREAM_FAILED, },
        STOPPED: {CREATED, SCHEDULED, RUNNING, WARNING, },
        SKIPPED: {CREATED, SCHEDULED, STOPPED, WARNING, },
        RETRYING: {SCHEDULED, RUNNING, FAILED, STOPPED, SKIPPED, RETRYING, WARNING, },
        WARNING: set(VALUES) - {SUCCEEDED, FAILED, STOPPED, UPSTREAM_FAILED, WARNING, },
    }


class TriggerPolicy(object):
    ALL_SUCCEEDED = 'all_succeeded'
    ALL_FAILED = 'all_failed'
    ALL_DONE = 'all_done'
    ONE_SUCCEEDED = 'one_succeeded'
    ONE_FAILED = 'one_failed'
    ONE_DONE = 'one_done'

    VALUES = {ALL_SUCCEEDED, ALL_FAILED, ALL_DONE, ONE_SUCCEEDED, ONE_FAILED, ONE_DONE}
    CHOICES = (
        (ALL_SUCCEEDED, ALL_SUCCEEDED),
        (ALL_FAILED, ALL_FAILED),
        (ALL_DONE, ALL_DONE),
        (ONE_SUCCEEDED, ONE_SUCCEEDED),
        (ONE_FAILED, ONE_FAILED),
        (ONE_DONE, ONE_DONE),
    )
